@@ -944,19 +944,19 @@ KeyCodeToCharRule scim_anthy_kana_table[] = {
 
 NicolaRule scim_anthy_nicola_table[] = {
 // no modifiered keys
-{"1",	"1",	"？",	"！"},
-{"2",	"2",	"／",	"゛"},
-{"3",	"3",	"〜",	"＃"},
-{"4",	"4",	"「",	"＄"},
-{"5",	"5",	"」",	"％"},
-{"6",	"6",	"＆",	"［"},
-{"7",	"7",	"’",	"］"},
-{"8",	"8",	"（",	"（"},
-{"9",	"9",	"）",	"）"},
-{"0",	"0",	"｛",	"｛"},
-{"-",	"−",	"｝",	"｝"},
-{"^",	"｜",	"￥",	"￥"},
-{"\\",	"￥",	"￥",	"￥"},
+{"1",	"１",	"？",	"！"},
+{"2",	"２",	"／",	"゛"},
+{"3",	"３",	"〜",	"＃"},
+{"4",	"４",	"「",	"＄"},
+{"5",	"５",	"」",	"％"},
+{"6",	"６",	"＆",	"［"},
+{"7",	"７",	"’",	"］"},
+{"8",	"８",	"（",	"（"},
+{"9",	"９",	"）",	"）"},
+{"0",	"０",	"〜",	"『"},
+{"-",	"−",	"＝",	"』"},
+{"^",	"＾",	"",	""},
+{"\\",	"￥",	"",	""},
 
 {"q",	"。",	"ぁ",	"ゐ"},
 {"w",	"か",	"え",	"が"},
@@ -968,8 +968,8 @@ NicolaRule scim_anthy_nicola_table[] = {
 {"i",	"く",	"ぐ",	"る"},
 {"o",	"つ",	"づ",	"ま"},
 {"p",	"，",	"ぴ",	"ぇ"},
-{"@",	"、",	"゛",	"ー"},
-{"[",	"「",	"『",	"『"},
+{"@",	"、",	"",	""},
+{"[",	"゛",	"゜",	"゜"},
 
 {"a",	"う",	"を",	"ヴ"},
 {"s",	"し",	"あ",	"じ"},
@@ -980,9 +980,9 @@ NicolaRule scim_anthy_nicola_table[] = {
 {"j",	"と",	"ど",	"お"},
 {"k",	"き",	"ぎ",	"の"},
 {"l",	"い",	"ぽ",	"ょ"},
-{";",	"ん",	"；",	"っ"},
-{":",	"：",	"：",	"："},
-{"]",	"」",	"』",	"』"},
+{";",	"ん",	"",	"っ"},
+{":",	"",	"",	""},
+{"]",	"",	"",	""},
 
 {"z",	"．",	"ぅ",	"ゑ"},
 {"x",	"ひ",	"ー",	"び"},
@@ -1021,5 +1021,42 @@ NicolaRule scim_anthy_nicola_table[] = {
 {"?",	"？",	"",	""},
 {"_",	"＿",	"",	""},
 
+{"Q",	"。",	"ぁ",	"ゐ"},
+{"W",	"が",	"え",	"が"},
+{"E",	"だ",	"り",	"だ"},
+{"R",	"ご",	"ゃ",	"ご"},
+{"T",	"ざ",	"れ",	"ざ"},
+{"Y",	"ぱ",	"ぱ",	"よ"},
+{"U",	"ぢ",	"ぢ",	"に"},
+{"I",	"ぐ",	"ぐ",	"る"},
+{"O",	"づ",	"づ",	"ま"},
+{"P",	"ぴ",	"ぴ",	"ぇ"},
+{"`",	"、",	"",	""},
+{"{",	"゛",	"゜",	"゜"},
+
+{"A",	"ヴ",	"を",	"ヴ"},
+{"S",	"じ",	"あ",	"じ"},
+{"D",	"で",	"な",	"で"},
+{"F",	"げ",	"ゅ",	"げ"},
+{"G",	"ぜ",	"も",	"ぜ"},
+{"H",	"ば",	"ば",	"み"},
+{"J",	"ど",	"ど",	"お"},
+{"K",	"ぎ",	"ぎ",	"の"},
+{"L",	"ぽ",	"ぽ",	"ょ"},
+{"+",	"ん",	"",	"っ"},
+{"*",	"",	"",	""},
+{"}",	"",	"",	""},
+
+{"Z",	"．",	"ぅ",	"ゑ"},
+{"X",	"び",	"ー",	"び"},
+{"C",	"ず",	"ろ",	"ず"},
+{"V",	"ぶ",	"や",	"ぶ"},
+{"B",	"べ",	"ぃ",	"べ"},
+{"N",	"ぷ",	"ぷ",	"ぬ"},
+{"M",	"ぞ",	"ぞ",	"ゆ"},
+{"<",	"ぺ",	"ぺ",	"む"},
+{">",	"ぽ",	"ぼ",	"わ"},
+{"?",	"・",	"ゎ",	"ぉ"},
+
 {NULL,	NULL,	NULL,	NULL},
 };
