@@ -88,7 +88,7 @@ extern "C" {
 
         try {
             factory = new AnthyFactory (String ("ja_JP"),
-                                        String ("fffb6633-7041-428e-9dfc-139117a71b6e"),
+                                        String ("065d7b20-dda2-47fb-8f94-3306d9a25e56"),
                                         _scim_config);
         } catch (...) {
             delete factory;
@@ -123,6 +123,8 @@ AnthyFactory::AnthyFactory (const String &lang,
       m_nicola_time                 (SCIM_ANTHY_CONFIG_NICOLA_TIME_DEFAULT),
       m_dict_admin_command          (SCIM_ANTHY_CONFIG_DICT_ADMIN_COMMAND_DEFAULT),
       m_add_word_command            (SCIM_ANTHY_CONFIG_ADD_WORD_COMMAND_DEFAULT),
+      m_predict_on_input            (SCIM_ANTHY_CONFIG_PREDICT_ON_INPUT_DEFAULT),
+      m_use_direct_key_on_predict   (SCIM_ANTHY_CONFIG_USE_DIRECT_KEY_ON_PREDICT_DEFAULT),
       m_show_input_mode_label       (SCIM_ANTHY_CONFIG_SHOW_INPUT_MODE_LABEL_DEFAULT),
       m_show_conv_mode_label        (SCIM_ANTHY_CONFIG_SHOW_INPUT_MODE_LABEL_DEFAULT),
       m_show_typing_method_label    (SCIM_ANTHY_CONFIG_SHOW_TYPING_METHOD_LABEL_DEFAULT),
@@ -178,21 +180,82 @@ AnthyFactory::get_name () const
 WideString
 AnthyFactory::get_authors () const
 {
-    return utf8_mbstowcs (
-        _("Copyright (C) 2004,2005 Takuro Ashie <ashie@homa.ne.jp>\n"
-          "Copyright (C) 2004,2005 Hiroyuki Ikezoe <poincare@ikezoe.net>"));
+    const char *package = 
+        PACKAGE "-" PACKAGE_VERSION "\n"
+        "\n";
+    const char *authors =
+        _("Authors of scim-anthy:\n"
+          "  Copyright (C) 2004,2005 Takuro Ashie <ashie@homa.ne.jp>\n"
+          "  Copyright (C) 2004,2005 Hiroyuki Ikezoe <poincare@ikezoe.net>\n"
+          "  \n"
+          "Authors of Anthy:\n"
+          "  Copyright (C) 2000-2005 Yusuke TABATA <yusuke@w5.dion.ne.jp>\n"
+          "  Copyright (C) 2004-2005 Yuichi YOSHIDA <oxy@kmc.gr.jp>\n"
+          "  You can find out all credits of Anthy from AUTHORS file in Anthy package.\n");
+
+    return utf8_mbstowcs (package) + utf8_mbstowcs (authors);
 }
 
 WideString
 AnthyFactory::get_credits () const
 {
-    return WideString ();
+    return utf8_mbstowcs (
+        _("Special thanks:\n"
+          "  UTUMI Hirosi <utuhiro78@yahoo.co.jp>\n"
+          "  Yukiko Bando <ybando@k6.dion.ne.jp>\n"
+          "  Mike Fabin <mfabin@suse.de>"
+          "  David Oftedal <david@start.no>\n"
+          "  Ryo Dairiki <ryo-dairiki@mbm.nifty.com>\n"
+          "  Seiichi SATO\n"
+          "  AWASHIRO Ikuya <ikuya@oooug.jp>\n"
+          "  Hatuka*nezumi <nezumi@jca.apc.org>"));
 }
 
 WideString
 AnthyFactory::get_help () const
 {
-    return WideString ();
+    const char *title = 
+        _("Basic operation:\n"
+          "  \n");
+
+    const char *text1 = 
+        _("1. Switch input mode:\n"
+          "  You can switch on/off Japanese input mode by pressing Zenkaku_Hankaku key\n"
+          "  or Control+J. Or you can rotate all input modes by pressing Control+,\n"
+          "  (comma).\n"
+          "  \n");
+
+    const char *text2 = 
+        _("2. Input Japanese hiragana and katakana:\n"
+          "  You can input Japanese hiragana and katakana by inputting romaji.\n"
+          "  Romaji table will be find out from \"Anthy\" section on a setup window of\n"
+          "  SCIM or SKIM.\n"
+          "  If you want to hiragana and katakana directly by using Japanese keyboard,\n"
+          "  please press Alt + Romaji key or Conrol+\\ key to switch typing method.\n"
+          "  \n");
+
+    const char *text3 = 
+        _("3. Convert hiragana or katakana to Japanese kanji\n"
+          "  After inputting hiragana or katakana, you can convert it to Japanese\n"
+          "  kanji by pressing Space key. Then it will show some candidates. You can\n"
+          "  select a next candidate by pressing Space key, and can commit it by\n"
+          "  pressing Enter key.\n"
+          "  If you input a sentense, Anthy will split it to some segments. You can\n"
+          "  select a next or previous segment by pressing left or right cursor key,\n"
+          "  and can extend or shrink the selected segment by pressing Shift + left or\n"
+          "  right cursor key.\n"
+          "  \n");
+
+    const char *text4 = 
+        _("4. Other key bindings:\n"
+          "  You can find out all key bindings definition of scim-anthy from \"Anthy\"\n"
+          "  section on setup window of SCIM or SKIM.\n");
+
+    return utf8_mbstowcs (title)
+        + utf8_mbstowcs (text1)
+        + utf8_mbstowcs (text2)
+        + utf8_mbstowcs (text3)
+        + utf8_mbstowcs (text4);
 }
 
 String
@@ -289,6 +352,7 @@ ANTHY_DEFINE_ACTION (action_do_nothing);
 ANTHY_DEFINE_ACTION (action_commit_follow_preference);
 ANTHY_DEFINE_ACTION (action_commit_reverse_preference);
 ANTHY_DEFINE_ACTION (action_convert);
+ANTHY_DEFINE_ACTION (action_predict);
 ANTHY_DEFINE_ACTION (action_revert);
 ANTHY_DEFINE_ACTION (action_cancel_all);
 ANTHY_DEFINE_ACTION (action_back);
@@ -335,12 +399,16 @@ ANTHY_DEFINE_ACTION (action_convert_to_half);
 ANTHY_DEFINE_ACTION (action_convert_to_half_katakana);
 ANTHY_DEFINE_ACTION (action_convert_to_latin);
 ANTHY_DEFINE_ACTION (action_convert_to_wide_latin);
-ANTHY_DEFINE_ACTION (action_toggle_latin_mode);
-ANTHY_DEFINE_ACTION (action_toggle_wide_latin_mode);
+ANTHY_DEFINE_ACTION (action_reconvert);
+ANTHY_DEFINE_ACTION (action_on_off);
+ANTHY_DEFINE_ACTION (action_circle_input_mode);
 ANTHY_DEFINE_ACTION (action_circle_kana_mode);
 ANTHY_DEFINE_ACTION (action_circle_typing_method);
+ANTHY_DEFINE_ACTION (action_latin_mode);
+ANTHY_DEFINE_ACTION (action_wide_latin_mode);
 ANTHY_DEFINE_ACTION (action_hiragana_mode);
 ANTHY_DEFINE_ACTION (action_katakana_mode);
+ANTHY_DEFINE_ACTION (action_half_katakana_mode);
 ANTHY_DEFINE_ACTION (action_launch_dict_admin_tool);
 ANTHY_DEFINE_ACTION (action_add_word);
 
@@ -434,6 +502,14 @@ AnthyFactory::reload_config (const ConfigPointer &config)
             = config->read (String (SCIM_ANTHY_CONFIG_ADD_WORD_COMMAND),
                             String (SCIM_ANTHY_CONFIG_ADD_WORD_COMMAND_DEFAULT));
 
+        m_predict_on_input
+            = config->read (String (SCIM_ANTHY_CONFIG_PREDICT_ON_INPUT),
+                            SCIM_ANTHY_CONFIG_PREDICT_ON_INPUT_DEFAULT);
+
+        m_use_direct_key_on_predict
+            = config->read (String (SCIM_ANTHY_CONFIG_USE_DIRECT_KEY_ON_PREDICT),
+                            SCIM_ANTHY_CONFIG_USE_DIRECT_KEY_ON_PREDICT_DEFAULT);
+
         m_show_input_mode_label
             = config->read (String (SCIM_ANTHY_CONFIG_SHOW_INPUT_MODE_LABEL),
                             SCIM_ANTHY_CONFIG_SHOW_INPUT_MODE_LABEL_DEFAULT);
@@ -523,6 +599,7 @@ AnthyFactory::reload_config (const ConfigPointer &config)
 
     // convert key
     APPEND_ACTION (CONVERT,                 action_convert);
+    APPEND_ACTION (PREDICT,                 action_predict);
 
     // candidates keys
     APPEND_ACTION (CANDIDATES_PAGE_UP,      action_candidates_page_up);
@@ -585,17 +662,23 @@ AnthyFactory::reload_config (const ConfigPointer &config)
     APPEND_ACTION (INSERT_WIDE_SPACE,       action_insert_wide_space);
 
     // mode keys
-    APPEND_ACTION (LATIN_MODE,              action_toggle_latin_mode);
-    APPEND_ACTION (WIDE_LATIN_MODE,         action_toggle_wide_latin_mode);
+    APPEND_ACTION (ON_OFF,                  action_on_off);
+    APPEND_ACTION (CIRCLE_INPUT_MODE,       action_circle_input_mode);
     APPEND_ACTION (CIRCLE_KANA_MODE,        action_circle_kana_mode);
     APPEND_ACTION (CIRCLE_TYPING_METHOD,    action_circle_typing_method);
+    APPEND_ACTION (LATIN_MODE,              action_latin_mode);
+    APPEND_ACTION (WIDE_LATIN_MODE,         action_wide_latin_mode);
     APPEND_ACTION (HIRAGANA_MODE,           action_hiragana_mode);
     APPEND_ACTION (KATAKANA_MODE,           action_katakana_mode);
+    APPEND_ACTION (HALF_KATAKANA_MODE,      action_half_katakana_mode);
 
     // dict keys
     APPEND_ACTION (DICT_ADMIN,              action_launch_dict_admin_tool);
     APPEND_ACTION (ADD_WORD,                action_add_word);
 
+    // reconvert
+    APPEND_ACTION (RECONVERT,               action_reconvert);
+
     // disabled key
     APPEND_ACTION (DO_NOTHING,              action_do_nothing);
 
