@@ -42,6 +42,7 @@
 #include "scim_anthy_prefs.h"
 #include "scim_anthy_intl.h"
 #include "scim_anthy_utils.h"
+#include "scim_anthy_helper.h"
 
 #define SCIM_PROP_PREFIX                     "/IMEngine/Anthy"
 #define SCIM_PROP_INPUT_MODE                 "/IMEngine/Anthy/InputMode"
@@ -84,7 +85,9 @@ AnthyInstance::AnthyInstance (AnthyFactory   *factory,
       m_lookup_table_visible   (false),
       m_n_conv_key_pressed     (0),
       m_prev_input_mode        (SCIM_ANTHY_MODE_HIRAGANA),
-      m_conv_mode              (SCIM_ANTHY_CONVERSION_MULTI_SEGMENT)
+      m_conv_mode              (SCIM_ANTHY_CONVERSION_MULTI_SEGMENT),
+      m_helper_started         (false),
+      m_timeout_id_seq         (0)
 {
     SCIM_DEBUG_IMENGINE(1) << "Create Anthy Instance : ";
 
@@ -95,6 +98,9 @@ AnthyInstance::AnthyInstance (AnthyFactory   *factory,
 
 AnthyInstance::~AnthyInstance ()
 {
+    if (m_helper_started)
+        stop_helper (String (SCIM_ANTHY_HELPER_UUID));
+
     m_factory->remove_config_listener (this);
 }
 
@@ -117,41 +123,57 @@ AnthyInstance::is_nicola_thumb_shift_key (const KeyEvent &key)
 bool
 AnthyInstance::process_key_event_input (const KeyEvent &key)
 {
-    if (m_preedit.can_process_key_event (key)) {
-        if (m_preedit.is_converting ()) {
-            if (is_realtime_conversion ()) {
-                action_revert ();
-            } else if (!is_nicola_thumb_shift_key (key)) {
-                action_commit (m_factory->m_learn_on_auto_commit);
-            }
-        }
-
-        bool need_commit = m_preedit.process_key_event (key);
-
-        if (need_commit) {
-            if (is_realtime_conversion () &&
-                get_input_mode () != SCIM_ANTHY_MODE_LATIN &&
-                get_input_mode () != SCIM_ANTHY_MODE_WIDE_LATIN)
-            {
-                m_preedit.convert (SCIM_ANTHY_CANDIDATE_NORMAL,
-                                   is_single_segment ());
-            }
-            action_commit (m_factory->m_learn_on_auto_commit);
+    // prediction while typing
+    if (m_factory->m_predict_on_input && key.is_key_release () &&
+        m_preedit.is_preediting () && !m_preedit.is_converting ())
+    {
+        CommonLookupTable table;
+        m_preedit.predict ();
+        m_preedit.get_candidates (table);
+        if (table.number_of_candidates () > 0) {
+            table.show_cursor (false);
+            update_lookup_table (table);
+            show_lookup_table ();
         } else {
-            if (is_realtime_conversion ()) {
-                m_preedit.convert (SCIM_ANTHY_CANDIDATE_NORMAL,
-                                   is_single_segment ());
-                m_preedit.select_segment (-1);
-            }
-            show_preedit_string ();
-            m_preedit_string_visible = true;
-            set_preedition ();
+            hide_lookup_table ();
         }
-
-        return true;
     }
 
-    return false;
+    if (!m_preedit.can_process_key_event (key)) {
+        return false;
+    }
+
+    if (m_preedit.is_converting ()) {
+        if (is_realtime_conversion ()) {
+            action_revert ();
+        } else if (!is_nicola_thumb_shift_key (key)) {
+            action_commit (m_factory->m_learn_on_auto_commit);
+        }
+    }
+
+    bool need_commit = m_preedit.process_key_event (key);
+
+    if (need_commit) {
+        if (is_realtime_conversion () &&
+            get_input_mode () != SCIM_ANTHY_MODE_LATIN &&
+            get_input_mode () != SCIM_ANTHY_MODE_WIDE_LATIN)
+        {
+            m_preedit.convert (SCIM_ANTHY_CANDIDATE_DEFAULT,
+                               is_single_segment ());
+        }
+        action_commit (m_factory->m_learn_on_auto_commit);
+    } else {
+        if (is_realtime_conversion ()) {
+            m_preedit.convert (SCIM_ANTHY_CANDIDATE_DEFAULT,
+                               is_single_segment ());
+            m_preedit.select_segment (-1);
+        }
+        show_preedit_string ();
+        m_preedit_string_visible = true;
+        set_preedition ();
+    }
+
+    return true;
 }
 
 bool
@@ -170,20 +192,49 @@ AnthyInstance::process_key_event_lookup_keybind (const KeyEvent& key)
 }
 
 bool
-AnthyInstance::process_key_event_without_preedit (const KeyEvent& key)
+AnthyInstance::process_key_event_latin_mode (const KeyEvent &key)
 {
-    return false;
+    if (key.is_key_release ())
+        return false;
+
+    if (util_key_is_keypad (key)) {
+        String str;
+        WideString wide;
+        util_keypad_to_string (str, key);
+        if (m_factory->m_ten_key_type == "Wide")
+            util_convert_to_wide (wide, str);
+        else
+            wide = utf8_mbstowcs (str);
+        if (wide.length () > 0) {
+            commit_string (wide);
+            return true;
+        } else {
+            return false;
+        }
+    } else {
+        // for Multi/Dead key
+        return false;
+    }
 }
 
 bool
-AnthyInstance::process_key_event_with_preedit (const KeyEvent& key)
+AnthyInstance::process_key_event_wide_latin_mode (const KeyEvent &key)
 {
-    return false;
-}
+    if (key.is_key_release ())
+        return false;
+
+    String str;
+    WideString wide;
+    util_keypad_to_string (str, key);
+    if (util_key_is_keypad (key) && m_factory->m_ten_key_type == "Half")
+        wide = utf8_mbstowcs (str);
+    else
+        util_convert_to_wide (wide, str);
+    if (wide.length () > 0) {
+        commit_string (wide);
+        return true;
+    }
 
-bool
-AnthyInstance::process_key_event_with_candidate (const KeyEvent &key)
-{
     return false;
 }
 
@@ -205,22 +256,15 @@ AnthyInstance::process_key_event (const KeyEvent& key)
     if (process_key_event_lookup_keybind (key))
         return true;
 
-    // process hard coded keys
-    if (is_selecting_candidates () && m_lookup_table_visible)
-        if (process_key_event_with_candidate (key))
-            return true;
-    else if (m_preedit.is_preediting ())
-        if (process_key_event_with_preedit(key))
-            return true;
-    else
-        if (process_key_event_without_preedit(key))
-            return true;
-
-    // for Multi/Dead key
+    // for Latin mode
     if (m_preedit.get_input_mode () == SCIM_ANTHY_MODE_LATIN)
-        return false;
+        return process_key_event_latin_mode (key);
 
-    // for input key event
+    // for wide Latin mode
+    if (m_preedit.get_input_mode () == SCIM_ANTHY_MODE_WIDE_LATIN)
+        process_key_event_wide_latin_mode (key);
+
+    // for other mode
     if (get_typing_method () != SCIM_ANTHY_TYPING_METHOD_NICOLA ||
         !is_nicola_thumb_shift_key (key))
     {
@@ -244,10 +288,13 @@ AnthyInstance::move_preedit_caret (unsigned int pos)
 void
 AnthyInstance::select_candidate_no_direct (unsigned int item)
 {
-    if (!is_selecting_candidates ()) return;
-
     SCIM_DEBUG_IMENGINE(2) << "select_candidate_no_direct.\n";
 
+    if (m_preedit.is_predicting () && !m_preedit.is_converting ())
+        action_predict ();
+
+    if (!is_selecting_candidates ()) return;
+
     // update lookup table
     m_lookup_table.set_cursor_pos_in_current_page (item);
     update_lookup_table (m_lookup_table);
@@ -327,7 +374,6 @@ AnthyInstance::reset ()
 
     m_preedit.clear ();
     m_lookup_table.clear ();
-
     unset_lookup_table ();
 
     hide_preedit_string ();
@@ -357,12 +403,25 @@ AnthyInstance::focus_in ()
     }
 
     install_properties ();
+
+    if (!m_helper_started)
+        start_helper (String (SCIM_ANTHY_HELPER_UUID));
+
+    Transaction send;
+    send.put_command (SCIM_TRANS_CMD_REQUEST);
+    send.put_command (SCIM_TRANS_CMD_FOCUS_IN);
+    send_helper_event (String (SCIM_ANTHY_HELPER_UUID), send);
 }
 
 void
 AnthyInstance::focus_out ()
 {
     SCIM_DEBUG_IMENGINE(2) << "focus_out.\n";
+
+    Transaction send;
+    send.put_command (SCIM_TRANS_CMD_REQUEST);
+    send.put_command (SCIM_TRANS_CMD_FOCUS_OUT);
+    send_helper_event (String (SCIM_ANTHY_HELPER_UUID), send);
 }
 
 void
@@ -404,9 +463,12 @@ AnthyInstance::set_lookup_table (void)
 
     }
 
-    if (!m_lookup_table_visible &&
+    bool beyond_threshold =
         m_factory->m_n_triggers_to_show_cand_win > 0 &&
-        (int) m_n_conv_key_pressed >= m_factory->m_n_triggers_to_show_cand_win)
+        (int) m_n_conv_key_pressed >= m_factory->m_n_triggers_to_show_cand_win;
+
+    if (!m_lookup_table_visible &&
+        (m_preedit.is_predicting () || beyond_threshold))
     {
         show_lookup_table ();
         m_lookup_table_visible = true;
@@ -420,6 +482,8 @@ AnthyInstance::set_lookup_table (void)
             update_aux_string (utf8_mbstowcs (buf));
             show_aux_string ();
         }
+    } else if (!m_lookup_table_visible) {
+        hide_lookup_table ();
     }
 }
 
@@ -764,7 +828,7 @@ AnthyInstance::action_convert (void)
     if (!m_preedit.is_converting ()) {
         // show conversion string
         m_preedit.finish ();
-        m_preedit.convert (SCIM_ANTHY_CANDIDATE_NORMAL,
+        m_preedit.convert (SCIM_ANTHY_CANDIDATE_DEFAULT,
                            is_single_segment ());
         set_preedition ();
         set_lookup_table ();
@@ -774,9 +838,37 @@ AnthyInstance::action_convert (void)
     return false;
 }
 
+bool
+AnthyInstance::action_predict (void)
+{
+    if (!m_preedit.is_preediting ())
+        return false;
+
+    if (m_preedit.is_converting ())
+        return false;
+
+    if (!m_preedit.is_predicting ())
+        m_preedit.predict ();
+
+    m_preedit.select_candidate (0);
+    set_preedition ();
+    set_lookup_table ();
+    select_candidate_no_direct (0);
+
+    return true;
+}
+
+
 bool
 AnthyInstance::action_revert (void)
 {
+    if (m_preedit.is_reconverting ()) {
+        m_preedit.revert ();
+        commit_string (m_preedit.get_string ());
+        reset ();
+        return true;
+    }
+
     if (!m_preedit.is_preediting ())
         return false;
 
@@ -794,7 +886,6 @@ AnthyInstance::action_revert (void)
     }
 
     unset_lookup_table ();
-
     m_preedit.revert ();
     set_preedition ();
 
@@ -859,7 +950,7 @@ AnthyInstance::action_back (void)
 
     if (m_preedit.get_length () > 0) {
         if (is_realtime_conversion ()) {
-            m_preedit.convert (SCIM_ANTHY_CANDIDATE_NORMAL,
+            m_preedit.convert (SCIM_ANTHY_CANDIDATE_DEFAULT,
                                is_single_segment ());
             m_preedit.select_segment (-1);
         }
@@ -887,7 +978,7 @@ AnthyInstance::action_delete (void)
 
     if (m_preedit.get_length () > 0) {
         if (is_realtime_conversion ()) {
-            m_preedit.convert (SCIM_ANTHY_CANDIDATE_NORMAL,
+            m_preedit.convert (SCIM_ANTHY_CANDIDATE_DEFAULT,
                                is_single_segment ());
             m_preedit.select_segment (-1);
         }
@@ -1334,12 +1425,21 @@ AnthyInstance::action_candidates_page_down (void)
 bool
 AnthyInstance::action_select_candidate (unsigned int i)
 {
-    if (!m_preedit.is_converting ()) return false;
-    if (!is_selecting_candidates ()) return false;
+    if (m_preedit.is_predicting () && !m_preedit.is_converting () &&
+        m_factory->m_use_direct_key_on_predict)
+    {
+        CommonLookupTable table;
+        m_preedit.get_candidates (table);
+        if (i < table.number_of_candidates ()) {
+            select_candidate (i);
+            return true;
+        }
+    } else if (m_preedit.is_converting () && is_selecting_candidates ()) {
+        select_candidate (i);
+        return true;
+    }
 
-    select_candidate (i);
-
-    return true;
+    return false;
 }
 
 bool
@@ -1406,7 +1506,7 @@ AnthyInstance::action_select_candidate_10 (void)
 bool
 AnthyInstance::action_circle_input_mode (void)
 {
-    InputMode mode = SCIM_ANTHY_MODE_HIRAGANA;
+    InputMode mode = get_input_mode ();
 
     switch (mode) {
     case SCIM_ANTHY_MODE_HIRAGANA:
@@ -1482,7 +1582,7 @@ AnthyInstance::action_circle_kana_mode (void)
 }
 
 bool
-AnthyInstance::action_toggle_latin_mode (void)
+AnthyInstance::action_on_off (void)
 {
     if (get_input_mode () == SCIM_ANTHY_MODE_LATIN ||
         get_input_mode () == SCIM_ANTHY_MODE_WIDE_LATIN)
@@ -1499,17 +1599,16 @@ AnthyInstance::action_toggle_latin_mode (void)
 }
 
 bool
-AnthyInstance::action_toggle_wide_latin_mode (void)
+AnthyInstance::action_latin_mode (void)
 {
-    if (get_input_mode () == SCIM_ANTHY_MODE_LATIN ||
-        get_input_mode () == SCIM_ANTHY_MODE_WIDE_LATIN)
-    {
-        set_input_mode (m_prev_input_mode);
-    } else {
-        m_prev_input_mode = get_input_mode ();
-        set_input_mode (SCIM_ANTHY_MODE_WIDE_LATIN);
-    }
+    set_input_mode (SCIM_ANTHY_MODE_LATIN);
+    return true;
+}
 
+bool
+AnthyInstance::action_wide_latin_mode (void)
+{
+    set_input_mode (SCIM_ANTHY_MODE_WIDE_LATIN);
     return true;
 }
 
@@ -1527,12 +1626,22 @@ AnthyInstance::action_katakana_mode (void)
     return true;
 }
 
+bool
+AnthyInstance::action_half_katakana_mode (void)
+{
+    set_input_mode (SCIM_ANTHY_MODE_HALF_KATAKANA);
+    return true;
+}
+
 bool
 AnthyInstance::convert_kana (CandidateType type)
 {
     if (!m_preedit.is_preediting ())
         return false;
 
+    if (m_preedit.is_reconverting ())
+        return false;
+
     unset_lookup_table ();
 
     if (m_preedit.is_converting ()) {
@@ -1686,6 +1795,19 @@ AnthyInstance::action_convert_char_type_backward (void)
     return true;
 }
 
+bool
+AnthyInstance::action_reconvert (void)
+{
+    if (m_preedit.is_preediting ())
+        return false;
+
+    Transaction send;
+    send.put_command (SCIM_ANTHY_TRANS_CMD_GET_SELECTION);
+    send_helper_event (String (SCIM_ANTHY_HELPER_UUID), send);
+
+    return true;
+}
+
 bool
 AnthyInstance::action_add_word (void)
 {
@@ -1727,6 +1849,41 @@ AnthyInstance::get_input_mode (void)
     return m_preedit.get_input_mode ();
 }
 
+int
+AnthyInstance::timeout_add (uint32 time_msec, timeout_func timeout_fn,
+                            void *data, delete_func delete_fn)
+{
+    uint32 id = ++m_timeout_id_seq;
+    m_closures[id] = TimeoutClosure (time_msec, timeout_fn, data, delete_fn);
+    /*
+     * FIXME! Obsoleted closures should be removed at somewhere.
+     * Currenly only NICOLA related timer uses this feature and it will be
+     * removed each time on key press event so memory leaks doesn't exit.
+     */
+
+    Transaction send;
+    send.put_command (SCIM_ANTHY_TRANS_CMD_TIMEOUT_ADD);
+    send.put_data (id);
+    send.put_data (time_msec);
+    send_helper_event (String (SCIM_ANTHY_HELPER_UUID), send);
+
+    return id;
+}
+
+void
+AnthyInstance::timeout_remove (uint32 id)
+{
+    if (m_closures.find (id) == m_closures.end ())
+        return;
+
+    m_closures.erase (id);
+
+    Transaction send;
+    send.put_command (SCIM_ANTHY_TRANS_CMD_TIMEOUT_REMOVE);
+    send.put_data (id);
+    send_helper_event (String (SCIM_ANTHY_HELPER_UUID), send);
+}
+
 void
 AnthyInstance::trigger_property (const String &property)
 {
@@ -1787,6 +1944,66 @@ AnthyInstance::trigger_property (const String &property)
     }
 }
 
+void
+AnthyInstance::process_helper_event (const String &helper_uuid,
+                                     const Transaction &recv)
+{
+    TransactionReader reader (recv);
+    int cmd;
+
+    if (helper_uuid != SCIM_ANTHY_HELPER_UUID)
+        return;
+
+    if (!reader.get_command (cmd))
+        return;
+
+    switch (cmd) {
+    case SCIM_ANTHY_TRANS_CMD_GET_SELECTION:
+    {
+        WideString selection, surround;
+        if (!reader.get_data (selection) || selection.empty ())
+            break;
+
+        int cursor;
+        unsigned int len = selection.length ();
+        if (!get_surrounding_text (surround, cursor, len, len))
+            break;
+
+        if (surround.length () - cursor >= len &&
+            surround.substr (cursor, len) == selection)
+        {
+            delete_surrounding_text (0, len);
+            m_preedit.convert (selection);
+            set_preedition ();
+            set_lookup_table ();
+        }
+
+        if (cursor >= (int) len &&
+            surround.substr (cursor - len, len) == selection)
+        {
+            delete_surrounding_text (0 - len, len);
+            m_preedit.convert (selection);
+            set_preedition ();
+            set_lookup_table ();
+        }
+        break;
+    }
+    case SCIM_ANTHY_TRANS_CMD_TIMEOUT_NOTIFY:
+    {
+        uint32 id;
+        if (reader.get_data (id) &&
+            m_closures.find (id) != m_closures.end ())
+        {
+            m_closures[id].close ();
+            m_closures.erase (id);
+        }
+        break;
+    }
+    default:
+        break;
+    }
+}
+
 void
 AnthyInstance::reload_config (const ConfigPointer &config)
 {
