@@ -28,6 +28,7 @@
 
 #define Uses_SCIM_IMENGINE
 #define Uses_SCIM_CONFIG_BASE
+#include <map>
 #include <anthy/anthy.h>
 #include <scim.h>
 #include "scim_anthy_preedit.h"
@@ -38,6 +39,8 @@ using namespace scim_anthy;
 
 class AnthyFactory;
 
+namespace scim_anthy {
+
 typedef enum {
     SCIM_ANTHY_CONVERSION_MULTI_SEGMENT,
     SCIM_ANTHY_CONVERSION_SINGLE_SEGMENT,
@@ -45,6 +48,45 @@ typedef enum {
     SCIM_ANTHY_CONVERSION_SINGLE_SEGMENT_IMMEDIATE,
 } ConversionMode;
 
+typedef void (*timeout_func) (void *data);
+typedef void (*delete_func)  (void *data);
+
+class TimeoutClosure
+{
+public:
+    TimeoutClosure ()
+        : m_time_msec  (0),
+          m_timeout_fn (NULL),
+          m_data       (NULL),
+          m_delete_fn  (NULL)
+        {}
+    TimeoutClosure  (uint32        time_msec,
+                     timeout_func  timeout_fn,
+                     void         *data,
+                     delete_func   delete_fn)
+        : m_time_msec  (time_msec),
+          m_timeout_fn (timeout_fn),
+          m_data       (data),
+          m_delete_fn  (delete_fn)
+        {}
+    virtual ~TimeoutClosure ()
+        {
+            if (m_delete_fn && m_data)
+                m_delete_fn (m_data);
+        }
+
+    void close (void) { m_timeout_fn (m_data); }
+private:
+    uint32        m_time_msec;
+    timeout_func  m_timeout_fn;
+    void         *m_data;
+    delete_func   m_delete_fn;
+};
+
+typedef std::map<int, TimeoutClosure>  TimeoutClosures;
+
+}
+
 class AnthyInstance : public IMEngineInstanceBase
 {
 public:
@@ -63,6 +105,8 @@ public:
     virtual void focus_in                     (void);
     virtual void focus_out                    (void);
     virtual void trigger_property             (const String &property);
+    virtual void process_helper_event         (const String &helper_uuid,
+                                               const Transaction &trans);
 
     virtual void reload_config                (const ConfigPointer &config);
 
@@ -71,6 +115,7 @@ public:
     bool   action_do_nothing                  (void);
 
     bool   action_convert                     (void);
+    bool   action_predict                     (void);
     bool   action_revert                      (void);
     bool   action_cancel_all                  (void);
     bool   action_commit_follow_preference    (void);
@@ -126,14 +171,19 @@ public:
     bool   action_convert_to_wide_latin       (void);
     bool   action_convert_char_type_forward   (void);
     bool   action_convert_char_type_backward  (void);
+    bool   action_reconvert                   (void);
+
+    bool   action_on_off                      (void);
 
     bool   action_circle_input_mode           (void);
-    bool   action_circle_typing_method        (void);
     bool   action_circle_kana_mode            (void);
-    bool   action_toggle_latin_mode           (void);
-    bool   action_toggle_wide_latin_mode      (void);
+    bool   action_circle_typing_method        (void);
+
+    bool   action_latin_mode                  (void);
+    bool   action_wide_latin_mode             (void);
     bool   action_hiragana_mode               (void);
     bool   action_katakana_mode               (void);
+    bool   action_half_katakana_mode          (void);
 
     bool   action_add_word                    (void);
     bool   action_launch_dict_admin_tool      (void);
@@ -148,14 +198,18 @@ public:
            get_typing_method                  (void);
     InputMode
            get_input_mode                     (void);
+    int    timeout_add                        (uint32        time_msec,
+                                               timeout_func  timeout_fn,
+                                               void         *data = NULL,
+                                               delete_func   delete_fn = NULL);
+    void   timeout_remove                     (uint32        id);
 
 private:
     /* processing key event */
     bool   process_key_event_input            (const KeyEvent &key);
     bool   process_key_event_lookup_keybind   (const KeyEvent &key);
-    bool   process_key_event_without_preedit  (const KeyEvent &key);
-    bool   process_key_event_with_preedit     (const KeyEvent &key);
-    bool   process_key_event_with_candidate   (const KeyEvent &key);
+    bool   process_key_event_latin_mode       (const KeyEvent &key);
+    bool   process_key_event_wide_latin_mode  (const KeyEvent &key);
 
     /* utility */
     void   set_preedition                     (void);
@@ -202,6 +256,13 @@ private:
 
     /*  */
     ConversionMode        m_conv_mode;
+
+    /* Helper */
+    bool                  m_helper_started;
+
+    /* timeout */
+    uint32                m_timeout_id_seq;
+    TimeoutClosures       m_closures;
 };
 #endif /* __SCIM_ANTHY_IMENGINE_H__ */
 /*
