@@ -31,17 +31,40 @@ NicolaConvertor::NicolaConvertor (AnthyInstance &anthy,
                                   Key2KanaTableSet &tables)
     : m_tables            (tables),
       m_anthy             (anthy),
-      m_case_sensitive    (false)
+      m_timer_id          (0),
+      m_processing_timeout(false)
 {
 }
 
 NicolaConvertor::~NicolaConvertor ()
 {
+    if (m_timer_id > 0)
+        m_anthy.timeout_remove (m_timer_id);
 }
 
 bool
 NicolaConvertor::can_append (const KeyEvent & key)
 {
+    if (key == m_through_key_event) {
+        m_through_key_event = KeyEvent ();
+        return false;
+    }
+
+    if (m_processing_timeout && !m_prev_thumb_key.empty()) {
+        emit_key_event (m_prev_thumb_key);
+        m_prev_thumb_key = KeyEvent ();
+        return false;
+    }
+
+    if (key.is_key_release () &&
+        (key.code != m_prev_char_key.code &&
+         key.code != m_prev_thumb_key.code &&
+         key.code != m_repeat_char_key.code &&
+         key.code != m_repeat_thumb_key.code))
+    {
+        return false;
+    }
+
     if (is_repeating ()) {
         if (key.is_key_press () &&
             (key == m_repeat_char_key || key == m_repeat_thumb_key) &&
@@ -51,11 +74,6 @@ NicolaConvertor::can_append (const KeyEvent & key)
         }
     }
 
-    if (key == m_through_key_event) {
-        m_through_key_event = KeyEvent ();
-        return false;
-    }
-
     // ignore short cut keys of apllication.
     if (key.mask & SCIM_KEY_ControlMask ||
         key.mask & SCIM_KEY_AltMask)
@@ -84,7 +102,7 @@ NicolaConvertor::search (const KeyEvent key,
     raw = key.get_ascii_code ();
 
     String str1;
-    if (m_case_sensitive)
+    if (get_case_sensitive ())
         str1 = raw;
     else
         str1 = tolower (key.get_ascii_code ());
@@ -100,7 +118,7 @@ NicolaConvertor::search (const KeyEvent key,
             String str2 = rules[i].get_sequence ();
 
             for (unsigned int k = 0;
-                 !m_case_sensitive && k < str2.length ();
+                 !get_case_sensitive () && k < str2.length ();
                  k++)
             {
                 str2[k] = tolower (str2[k]);
@@ -128,6 +146,61 @@ NicolaConvertor::search (const KeyEvent key,
     }
 }
 
+bool
+NicolaConvertor::handle_voiced_consonant  (WideString & result,
+                                           WideString & pending)
+{
+    VoicedConsonantRule *table = scim_anthy_voiced_consonant_table;
+
+    if (result.empty ())
+        return false;
+
+    if (m_pending.empty ()) {
+        for (unsigned int i = 0; table[i].string; i++) {
+            if (result == utf8_mbstowcs (table[i].string)) {
+                pending = m_pending = result;
+                result = WideString ();
+                return false;
+            }
+        }
+
+    } else if (result == utf8_mbstowcs ("\xE3\x82\x9B")) {
+        // voiced consonant
+        for (unsigned int i = 0; table[i].string; i++) {
+            if (m_pending == utf8_mbstowcs (table[i].string)) {
+                result = utf8_mbstowcs (table[i].voiced);
+                m_pending = WideString ();
+                return false;
+            }
+        }
+        return true;
+
+    } else if (result == utf8_mbstowcs ("\xE3\x82\x9C")) {
+        // half voiced consonant
+        for (unsigned int i = 0; table[i].string; i++) {
+            if (m_pending == utf8_mbstowcs (table[i].string)) {
+                result = utf8_mbstowcs (table[i].half_voiced);
+                m_pending = WideString ();
+                return false;
+            }
+        }
+        return true;
+
+    } else {
+        m_pending = WideString ();
+        for (unsigned int i = 0; table[i].string; i++) {
+            if (result == utf8_mbstowcs (table[i].string)) {
+                pending = m_pending = result;
+                result = WideString ();
+                return true;
+            }
+        }
+        return true;
+    }
+
+    return false;
+}
+
 bool
 NicolaConvertor::is_char_key (const KeyEvent key)
 {
@@ -180,11 +253,13 @@ NicolaConvertor::on_key_repeat (const KeyEvent key,
 {
     if (key.is_key_release ()) {
         if (!m_repeat_char_key.empty ())
-            emmit_key_event (key);
+            emit_key_event (key);
         m_repeat_char_key  = KeyEvent ();
         m_repeat_thumb_key = KeyEvent ();
         m_prev_char_key    = KeyEvent ();
+#if 1
         m_prev_thumb_key   = KeyEvent ();
+#endif
 
     } else if (key == m_repeat_char_key || key == m_repeat_thumb_key) {
         if (!m_repeat_char_key.empty ()) {
@@ -200,14 +275,14 @@ NicolaConvertor::on_key_repeat (const KeyEvent key,
         m_repeat_thumb_key = KeyEvent ();
         m_prev_char_key    = key;
         m_prev_thumb_key   = KeyEvent ();
-        // set_alarm (m_e_time_char);
+        set_alarm (m_anthy.get_factory()->m_nicola_time);
 
     } else if (key == m_prev_thumb_key) {
         m_repeat_char_key  = KeyEvent ();
         m_repeat_thumb_key = KeyEvent ();
         m_prev_char_key    = KeyEvent ();
         m_prev_thumb_key   = key;
-        // set_alarm (m_e_time_thumb);
+        set_alarm (m_anthy.get_factory()->m_nicola_time);
 
     } else {
         m_repeat_char_key  = KeyEvent ();
@@ -255,8 +330,10 @@ NicolaConvertor::on_both_key_pressed (const KeyEvent key,
                 search (m_prev_char_key, get_thumb_key_type (m_prev_thumb_key),
                         result, raw);
                 m_prev_char_key  = key;
+#if 1
                 m_prev_thumb_key = KeyEvent ();
-                // set_alarm (m_e_char_time);
+#endif
+                set_alarm (m_anthy.get_factory()->m_nicola_time);
             }
 
         } else {
@@ -271,7 +348,9 @@ NicolaConvertor::on_both_key_pressed (const KeyEvent key,
                 search (m_prev_char_key, get_thumb_key_type (m_prev_thumb_key),
                         result, raw);
                 m_prev_char_key  = KeyEvent ();
+#if 1
                 m_prev_thumb_key = KeyEvent ();
+#endif
             }
         }
 
@@ -282,7 +361,7 @@ NicolaConvertor::on_both_key_pressed (const KeyEvent key,
             m_prev_char_key  = KeyEvent ();
             m_prev_thumb_key = key;
             gettimeofday (&m_time_thumb, NULL);
-            // set_alarm (m_e_time_thumb);
+            set_alarm (m_anthy.get_factory()->m_nicola_time);
 
         } else {
             search (m_prev_char_key, get_thumb_key_type (m_prev_thumb_key),
@@ -305,15 +384,17 @@ NicolaConvertor::on_thumb_key_pressed (const KeyEvent key,
                                        String &raw)
 {
     if (key.is_key_press () && key == m_prev_thumb_key) {
+#if 1
         m_repeat_thumb_key = key;
+#endif
 
     } else if (is_thumb_key (key) && key.is_key_release ()) {
-        emmit_key_event (m_prev_thumb_key);
-        emmit_key_event (key);
+        emit_key_event (m_prev_thumb_key); // key press event
+        emit_key_event (key);              // key release event
         m_prev_thumb_key = KeyEvent ();
 
     } else if (is_thumb_key (key) & key.is_key_press ()) {
-        emmit_key_event (m_prev_thumb_key);
+        emit_key_event (m_prev_thumb_key);
         m_prev_thumb_key = key;
         gettimeofday (&m_time_thumb, NULL);
 
@@ -348,12 +429,12 @@ NicolaConvertor::on_char_key_pressed (const KeyEvent key,
                 result, raw);
         m_prev_char_key = key;
         gettimeofday (&m_time_char, NULL);
-        // set_alram (m_e_time_char);
+        set_alarm (m_anthy.get_factory()->m_nicola_time);
 
     } else if (is_thumb_key (key) && key.is_key_press ()) {
         m_prev_thumb_key = key;
         gettimeofday (&m_time_thumb, NULL);
-        // set_alram (m_e_time_thumb);
+        set_alarm (m_anthy.get_factory()->m_nicola_time);
 
     } else if (key.is_key_release () && key == m_prev_char_key) {
         search (m_prev_char_key, SCIM_ANTHY_NICOLA_SHIFT_NONE,
@@ -376,11 +457,11 @@ NicolaConvertor::on_no_key_pressed (const KeyEvent key)
     if (is_char_key (key)) {
         m_prev_char_key = key;
         gettimeofday (&m_time_char, NULL);
-        // set_alarm (m_e_time_char);
+        set_alarm (m_anthy.get_factory()->m_nicola_time);
     } else if (is_thumb_key (key)) {
         m_prev_thumb_key = key;
         gettimeofday (&m_time_thumb, NULL);
-        // set_alarm (m_e_time_thumb);
+        set_alarm (m_anthy.get_factory()->m_nicola_time);
     }
 }
 
@@ -391,7 +472,7 @@ NicolaConvertor::is_repeating (void)
 }
 
 void
-NicolaConvertor::emmit_key_event (const KeyEvent & key)
+NicolaConvertor::emit_key_event (const KeyEvent & key)
 {
     m_through_key_event = key;
 
@@ -399,12 +480,81 @@ NicolaConvertor::emmit_key_event (const KeyEvent & key)
     m_anthy.process_key_event (key);
 }
 
+static void
+timeout_emit_key_event (void *data)
+{
+    NicolaConvertor *nicola = static_cast<NicolaConvertor*> (data);
+    nicola->process_timeout ();
+}
+
+void
+NicolaConvertor::process_timeout (void)
+{
+    m_processing_timeout = true;
+    if (!m_prev_char_key.empty ())
+        m_anthy.process_key_event (m_prev_char_key);
+    else if (!m_prev_thumb_key.empty ())
+        m_anthy.process_key_event (m_prev_thumb_key);
+    m_processing_timeout = false;
+}
+
+void
+NicolaConvertor::set_alarm (int time_msec)
+{
+    if (time_msec < 5)
+        time_msec = 5;
+    if (time_msec > 1000)
+        time_msec = 1000;
+
+    m_timer_id = m_anthy.timeout_add (time_msec,
+                                      timeout_emit_key_event,
+                                      (void *) this);
+}
+
 bool
 NicolaConvertor::append (const KeyEvent & key,
                          WideString & result,
                          WideString & pending,
                          String &raw)
 {
+    if (m_timer_id > 0) {
+        m_anthy.timeout_remove (m_timer_id);
+        m_timer_id = 0;
+    }
+
+    if (m_processing_timeout) {
+        search (m_prev_char_key, SCIM_ANTHY_NICOLA_SHIFT_NONE,
+                result, raw);
+        m_prev_char_key = KeyEvent ();
+        return handle_voiced_consonant (result, pending);
+    }
+
+    if (key.is_key_press () && util_key_is_keypad (key)) {
+        util_keypad_to_string (raw, key);
+
+        // convert key pad string to wide
+        WideString wide;
+        String ten_key_type = m_anthy.get_factory()->m_ten_key_type;
+        if ((ten_key_type == "FollowMode" &&
+             (m_anthy.get_input_mode () == SCIM_ANTHY_MODE_LATIN ||
+              m_anthy.get_input_mode () == SCIM_ANTHY_MODE_HALF_KATAKANA)) ||
+            ten_key_type == "Half")
+        {
+            wide = utf8_mbstowcs (raw);
+        } else {
+            util_convert_to_wide (wide, raw);
+        }
+
+        result = wide;
+
+        m_repeat_char_key  = KeyEvent ();
+        m_repeat_thumb_key = KeyEvent ();
+        m_prev_char_key    = KeyEvent ();
+        m_prev_thumb_key   = KeyEvent ();
+
+        return handle_voiced_consonant (result, pending);
+    }
+
     if (is_repeating ()) {
         on_key_repeat (key, result, raw);
 
@@ -421,32 +571,25 @@ NicolaConvertor::append (const KeyEvent & key,
         on_no_key_pressed (key);
     }
 
-    return false;
-}
-
-bool
-NicolaConvertor::append (const String   & str,
-                         WideString     & result,
-                         WideString     & pending)
-{
-    return false;
+    return handle_voiced_consonant (result, pending);
 }
 
 void
 NicolaConvertor::clear (void)
 {
+    m_pending = WideString ();
 }
 
 bool
 NicolaConvertor::is_pending (void)
 {
-    return false;
+    return !m_pending.empty ();
 }
 
 WideString
 NicolaConvertor::get_pending (void)
 {
-    return WideString ();
+    return m_pending;
 }
 
 WideString
@@ -456,15 +599,18 @@ NicolaConvertor::flush_pending (void)
 }
 
 void
-NicolaConvertor::set_case_sensitive (bool sens)
+NicolaConvertor::reset_pending (const WideString & result, const String & raw)
 {
-    m_case_sensitive = sens;
-}
+    VoicedConsonantRule *table = scim_anthy_voiced_consonant_table;
 
-bool
-NicolaConvertor::get_case_sensitive (void)
-{
-    return m_case_sensitive;
+    m_pending = WideString ();
+
+    for (unsigned int i = 0; table[i].string; i++) {
+        if (result == utf8_mbstowcs (table[i].string)) {
+            m_pending = result;
+            return;
+        }
+    }
 }
 /*
 vi:ts=4:nowrap:ai:expandtab
