@@ -66,6 +66,8 @@ Preedit::get_string (void)
 {
     if (is_converting ()) {
         return m_conversion.get ();
+    } else if (!m_source.empty ()) {
+        return m_source;
     } else {
         WideString widestr;
         switch (m_input_mode) {
@@ -118,10 +120,14 @@ Preedit::get_reading (void)
 bool
 Preedit::is_preediting (void)
 {
-    if (m_reading.get_length () > 0)
+    if (m_reading.get_length () > 0 ||
+        m_conversion.is_converting () ||
+        !m_source.empty ())
+    {
         return true;
-    else
+    } else {
         return false;
+    }
 }
 
 bool
@@ -130,6 +136,18 @@ Preedit::is_converting (void)
     return m_conversion.is_converting ();
 }
 
+bool
+Preedit::is_predicting (void)
+{
+    return m_conversion.is_predicting ();
+}
+
+bool
+Preedit::is_reconverting (void)
+{
+    return !m_source.empty ();
+}
+
 
 /*
  * manipulating the preedit string
@@ -158,7 +176,7 @@ Preedit::process_key_event (const KeyEvent & key)
     unsigned int len = m_reading.get_length ();
     if (len > 0) {
         String str;
-        m_reading.get_raw (str, len - 1, 1);
+        str = m_reading.get_raw (len - 1, 1);
         if (is_comma_or_period (str)) {
             if (m_anthy.get_factory()->m_behavior_on_period == "Convert" &&
                 get_length () > 1)
@@ -209,7 +227,17 @@ Preedit::finish (void)
 void
 Preedit::convert (CandidateType type, bool single_segment)
 {
-    m_conversion.start (type, single_segment);
+    if (m_source.empty ())
+        m_conversion.convert (type, single_segment);
+    else
+        m_conversion.convert (m_source, single_segment);
+}
+
+void
+Preedit::convert (const WideString &source, bool single_segment)
+{
+    m_conversion.convert (source, single_segment);
+    m_source = source;
 }
 
 void
@@ -298,8 +326,8 @@ Preedit::get_caret_pos (void)
         if (get_input_mode () == SCIM_ANTHY_MODE_HALF_KATAKANA) {
             // FIXME! It's ad-hoc
             WideString substr;
-            m_reading.get (substr, 0, m_reading.get_caret_pos (),
-                           SCIM_ANTHY_STRING_HALF_KATAKANA);
+            substr = m_reading.get (0, m_reading.get_caret_pos (),
+                                    SCIM_ANTHY_STRING_HALF_KATAKANA);
             return substr.length ();
         } else {
             return m_reading.get_caret_pos ();
@@ -330,6 +358,12 @@ Preedit::move_caret (int step)
     m_reading.move_caret (step, allow_split);
 }
 
+void
+Preedit::predict (void)
+{
+    m_conversion.predict ();
+}
+
 
 /*
  * clear all string
@@ -339,6 +373,7 @@ Preedit::clear (void)
 {
     m_reading.clear ();
     m_conversion.clear ();
+    m_source = WideString ();
 }
 
 
