@@ -57,6 +57,8 @@ public:
 
     virtual bool          is_preediting          (void);
     virtual bool          is_converting          (void);
+    virtual bool          is_predicting          (void);
+    virtual bool          is_reconverting        (void);
 
     // manipulating the preedit string
     virtual bool          can_process_key_event  (const KeyEvent & key);
@@ -67,7 +69,9 @@ public:
 
     // manipulating the conversion string
     virtual void          convert                (CandidateType type
-                                                  = SCIM_ANTHY_CANDIDATE_NORMAL,
+                                                  = SCIM_ANTHY_CANDIDATE_DEFAULT,
+                                                  bool single_segment = false);
+    virtual void          convert                (const WideString &source,
                                                   bool single_segment = false);
     virtual void          revert                 (void);
     virtual void          commit                 (int  segment_id = -1,
@@ -94,6 +98,9 @@ public:
     virtual void          set_caret_pos          (unsigned int   pos);
     virtual void          move_caret             (int            len);
 
+    // prediction
+    virtual void          predict                (void);
+
     // clear all string
     virtual void          clear                  (void);
 
@@ -127,6 +134,9 @@ private:
 
     // mode flags
     InputMode         m_input_mode;
+
+    // source string for reconversion
+    WideString        m_source;
 };
 
 }
