@@ -10,7 +10,7 @@
  *
  *  This program is distributed in the hope that it will be useful,
  *  but WITHOUT ANY WARRANTY; without even the implied warranty of
- *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+ *  MERCHANTABILITY or FITNESS FOR A PARTICUoLAR PURPOSE.  See the
  *  GNU General Public License for more details.
  *
  *  You should have received a copy of the GNU General Public License
@@ -41,7 +41,7 @@ BoolConfigData config_bool_common [] =
         SCIM_ANTHY_CONFIG_CLOSE_CAND_WIN_ON_SELECT,
         SCIM_ANTHY_CONFIG_CLOSE_CAND_WIN_ON_SELECT_DEFAULT,
         SCIM_ANTHY_CONFIG_CLOSE_CAND_WIN_ON_SELECT_DEFAULT,
-        N_("Close candidate window when select a candidate _directly."),
+        N_("Close candidate window when select a candidate _directly"),
         NULL,
         NULL,
         NULL,
@@ -51,7 +51,7 @@ BoolConfigData config_bool_common [] =
         SCIM_ANTHY_CONFIG_LEARN_ON_MANUAL_COMMIT,
         SCIM_ANTHY_CONFIG_LEARN_ON_MANUAL_COMMIT_DEFAULT,
         SCIM_ANTHY_CONFIG_LEARN_ON_MANUAL_COMMIT_DEFAULT,
-        N_("Learn on _manual committing."),
+        N_("Learn on _manual committing"),
         NULL,
         NULL,
         NULL,
@@ -61,7 +61,7 @@ BoolConfigData config_bool_common [] =
         SCIM_ANTHY_CONFIG_LEARN_ON_AUTO_COMMIT,
         SCIM_ANTHY_CONFIG_LEARN_ON_AUTO_COMMIT_DEFAULT,
         SCIM_ANTHY_CONFIG_LEARN_ON_AUTO_COMMIT_DEFAULT,
-        N_("Learn on a_uto committing."),
+        N_("Learn on a_uto committing"),
         NULL,
         NULL,
         NULL,
@@ -96,6 +96,24 @@ BoolConfigData config_bool_common [] =
         N_("If this check is enabled, you can delete each letter."),
         false,
     },
+    {
+        SCIM_ANTHY_CONFIG_PREDICT_ON_INPUT,
+        SCIM_ANTHY_CONFIG_PREDICT_ON_INPUT_DEFAULT,
+        SCIM_ANTHY_CONFIG_PREDICT_ON_INPUT_DEFAULT,
+        N_("_Show predicted candidates while inputting letters"),
+        NULL,
+        NULL,
+        false,
+    },
+    {
+        SCIM_ANTHY_CONFIG_USE_DIRECT_KEY_ON_PREDICT,
+        SCIM_ANTHY_CONFIG_USE_DIRECT_KEY_ON_PREDICT_DEFAULT,
+        SCIM_ANTHY_CONFIG_USE_DIRECT_KEY_ON_PREDICT_DEFAULT,
+        N_("Use _direct select keys while predicting"),
+        NULL,
+        NULL,
+        false,
+    },
     {
         SCIM_ANTHY_CONFIG_SHOW_INPUT_MODE_LABEL,
         SCIM_ANTHY_CONFIG_SHOW_INPUT_MODE_LABEL_DEFAULT,
@@ -209,11 +227,11 @@ IntConfigData config_int_common [] =
         SCIM_ANTHY_CONFIG_NICOLA_TIME,
         SCIM_ANTHY_CONFIG_NICOLA_TIME_DEFAULT,
         SCIM_ANTHY_CONFIG_NICOLA_TIME_DEFAULT,
-        0, 10000, 1,
-        N_("NICOLA time:"),
+        5, 1000, 1,
+        N_("_Simultaneous pressing time:"),
         N_("[msec]"),
         NULL,
-        N_("NICOLA time"),
+        N_("Time to regard as simultaneous key pressing."),
         NULL,
         false,
     },
@@ -359,7 +377,7 @@ StringConfigData config_string_common [] =
         SCIM_ANTHY_CONFIG_DICT_ADMIN_COMMAND,
         SCIM_ANTHY_CONFIG_DICT_ADMIN_COMMAND_DEFAULT,
         SCIM_ANTHY_CONFIG_DICT_ADMIN_COMMAND_DEFAULT,
-        N_("_Edit dictionary command:"),
+        N_("\"_Edit dictionary\" command:"),
         NULL,
         NULL,
         NULL,
@@ -369,7 +387,7 @@ StringConfigData config_string_common [] =
         SCIM_ANTHY_CONFIG_ADD_WORD_COMMAND,
         SCIM_ANTHY_CONFIG_ADD_WORD_COMMAND_DEFAULT,
         SCIM_ANTHY_CONFIG_ADD_WORD_COMMAND_DEFAULT,
-        N_("_Add word command:"),
+        N_("\"_Add word\" command:"),
         NULL,
         NULL,
         NULL,
@@ -499,6 +517,16 @@ StringConfigData config_keyboards_edit [] =
         NULL,
         false,
     },
+    {
+        SCIM_ANTHY_CONFIG_PREDICT_KEY,
+        SCIM_ANTHY_CONFIG_PREDICT_KEY_DEFAULT,
+        SCIM_ANTHY_CONFIG_PREDICT_KEY_DEFAULT,
+        N_("Predict"),
+        N_("Select predict keys"),
+        N_("The key events to predict a word or sentence from already inserted text. "),
+        NULL,
+        false,
+    },
     {
         SCIM_ANTHY_CONFIG_CANCEL_KEY,
         SCIM_ANTHY_CONFIG_CANCEL_KEY_DEFAULT,
@@ -519,6 +547,16 @@ StringConfigData config_keyboards_edit [] =
         NULL,
         false,
     },
+    {
+        SCIM_ANTHY_CONFIG_RECONVERT_KEY,
+        SCIM_ANTHY_CONFIG_RECONVERT_KEY_DEFAULT,
+        SCIM_ANTHY_CONFIG_RECONVERT_KEY_DEFAULT,
+        N_("Reconvert"),
+        N_("Select reconvert keys"),
+        N_("The key events to reconvert the commited string in selection. "),
+        NULL,
+        false,
+    },
     {
         SCIM_ANTHY_CONFIG_DO_NOTHING_KEY,
         SCIM_ANTHY_CONFIG_DO_NOTHING_KEY_DEFAULT,
@@ -974,6 +1012,26 @@ StringConfigData config_keyboards_converting [] =
 
 StringConfigData config_keyboards_mode [] =
 {
+    {
+        SCIM_ANTHY_CONFIG_ON_OFF_KEY,
+        SCIM_ANTHY_CONFIG_ON_OFF_KEY_DEFAULT,
+        SCIM_ANTHY_CONFIG_ON_OFF_KEY_DEFAULT,
+        N_("Toggle on/off"),
+        N_("Select toggle on/off keys"),
+        N_("The key events to toggle on/off Japanese mode. "),
+        NULL,
+        false,
+    },
+    {
+        SCIM_ANTHY_CONFIG_CIRCLE_INPUT_MODE_KEY,
+        SCIM_ANTHY_CONFIG_CIRCLE_INPUT_MODE_KEY_DEFAULT,
+        SCIM_ANTHY_CONFIG_CIRCLE_INPUT_MODE_KEY_DEFAULT,
+        N_("Circle input mode"),
+        N_("Select circle input mode keys"),
+        N_("The key events to circle input mode. "),
+        NULL,
+        false,
+    },
     {
         SCIM_ANTHY_CONFIG_CIRCLE_KANA_MODE_KEY,
         SCIM_ANTHY_CONFIG_CIRCLE_KANA_MODE_KEY_DEFAULT,
@@ -989,8 +1047,8 @@ StringConfigData config_keyboards_mode [] =
         SCIM_ANTHY_CONFIG_LATIN_MODE_KEY_DEFAULT,
         SCIM_ANTHY_CONFIG_LATIN_MODE_KEY_DEFAULT,
         N_("Latin mode"),
-        N_("Select latin mode keys"),
-        N_("The key events to toggle latin mode. "),
+        N_("Select Latin mode keys"),
+        N_("The key events to switch input mode to Latin. "),
         NULL,
         false,
     },
@@ -998,9 +1056,9 @@ StringConfigData config_keyboards_mode [] =
         SCIM_ANTHY_CONFIG_WIDE_LATIN_MODE_KEY,
         SCIM_ANTHY_CONFIG_WIDE_LATIN_MODE_KEY_DEFAULT,
         SCIM_ANTHY_CONFIG_WIDE_LATIN_MODE_KEY_DEFAULT,
-        N_("Wide latin mode"),
-        N_("Select wide latin mode keys"),
-        N_("The key events to toggle wide latin mode. "),
+        N_("Wide Latin mode"),
+        N_("Select wide Latin mode keys"),
+        N_("The key events to switch input mode to wide Latin. "),
         NULL,
         false,
     },
@@ -1010,7 +1068,7 @@ StringConfigData config_keyboards_mode [] =
         SCIM_ANTHY_CONFIG_HIRAGANA_MODE_KEY_DEFAULT,
         N_("Hiragana mode"),
         N_("Select hiragana mode keys"),
-        N_("The key events to switch to hiragana mode. "),
+        N_("The key events to switch input mode to hiragana. "),
         NULL,
         false,
     },
@@ -1020,7 +1078,17 @@ StringConfigData config_keyboards_mode [] =
         SCIM_ANTHY_CONFIG_KATAKANA_MODE_KEY_DEFAULT,
         N_("Katakana mode"),
         N_("Select katakana mode keys"),
-        N_("The key events to switch to katakana mode. "),
+        N_("The key events to switch input mode to katakana. "),
+        NULL,
+        false,
+    },
+    {
+        SCIM_ANTHY_CONFIG_HALF_KATAKANA_MODE_KEY,
+        SCIM_ANTHY_CONFIG_HALF_KATAKANA_MODE_KEY_DEFAULT,
+        SCIM_ANTHY_CONFIG_HALF_KATAKANA_MODE_KEY_DEFAULT,
+        N_("Half katakana mode"),
+        N_("Select half katakana mode keys"),
+        N_("The key events to switch input mode to half katakana. "),
         NULL,
         false,
     },
