@@ -206,33 +206,28 @@ Reading::clear (void)
 }
 
 WideString
-Reading::get (unsigned int start, int end, StringType type)
+Reading::get (unsigned int start, int len, StringType type)
 {
     WideString str;
-    get (str, start, end, type);
-    return str;
-}
-
-void
-Reading::get (WideString & str, unsigned int start, int len, StringType type)
-{
     unsigned int pos = 0, end = len > 0 ? start + len : get_length () - start;
     WideString kana;
     String raw;
 
-    if (start >= end) return;
-    if (start >= get_length ()) return;
+    if (start >= end)
+        return str;
+    if (start >= get_length ())
+        return str;
 
     switch (type) {
     case SCIM_ANTHY_STRING_LATIN:
-        get_raw (raw, start, len);
+        raw = get_raw (start, len);
         str = utf8_mbstowcs (raw);
-        return;
+        return str;
 
     case SCIM_ANTHY_STRING_WIDE_LATIN:
-        get_raw (raw, start, len);
+        raw = get_raw (start, len);
         util_convert_to_wide (str, raw);
-        return;
+        return str;
 
     default:
         break;
@@ -276,22 +271,18 @@ Reading::get (WideString & str, unsigned int start, int len, StringType type)
     default:
         break;
     }
-}
 
-String
-Reading::get_raw (unsigned int start, int end)
-{
-    String str;
-    get_raw (str, start, end);
     return str;
 }
 
-void
-Reading::get_raw (String & str, unsigned int start, int len)
+String
+Reading::get_raw (unsigned int start, int len)
 {
+    String str;
     unsigned int pos = 0, end = len > 0 ? start + len : get_length () - start;
 
-    if (start >= end) return;
+    if (start >= end)
+        return str;
 
     for (unsigned int i = 0; i < m_segments.size (); i++) {
         if (pos >= start || pos + m_segments[i].kana.length () > start) {
@@ -304,6 +295,8 @@ Reading::get_raw (String & str, unsigned int start, int len)
         if (pos >= end)
             break;
     }
+
+    return str;
 }
 
 void
@@ -428,20 +421,16 @@ Reading::reset_pending (void)
 {
     if (m_key2kana->is_pending ())
         m_key2kana->clear ();
+    if (m_kana.is_pending ())
+        m_kana.clear ();
 
     if (m_segment_pos <= 0)
         return;
 
-    for (unsigned int i = 0;
-         i < m_segments[m_segment_pos - 1].raw.length ();
-         i++)
-    {
-        WideString result, pending;
-        m_key2kana->append (m_segments[m_segment_pos - 1].raw.substr(i, 1),
-                            result, pending);
-    }
-
-    m_kana.set_pending (utf8_wcstombs (m_segments[m_segment_pos - 1].kana));
+    m_key2kana->reset_pending (m_segments[m_segment_pos - 1].kana,
+                               m_segments[m_segment_pos - 1].raw);
+    m_kana.reset_pending (m_segments[m_segment_pos - 1].kana,
+                          m_segments[m_segment_pos - 1].raw);
 }
 
 unsigned int
@@ -567,20 +556,18 @@ Reading::set_typing_method (TypingMethod method)
         fundamental_table = m_anthy.get_factory()->m_custom_nicola_table;
         m_key2kana = &m_nicola;
         m_nicola_tables.set_typing_method (method, fundamental_table);
+        m_nicola.set_case_sensitive (false);
     } else if (method == SCIM_ANTHY_TYPING_METHOD_KANA) {
         fundamental_table = m_anthy.get_factory()->m_custom_kana_table;
         m_key2kana = &m_key2kana_normal;
         m_key2kana_tables.set_typing_method (method, fundamental_table);
+        m_key2kana_normal.set_case_sensitive (true);
     } else {
         fundamental_table = m_anthy.get_factory()->m_custom_romaji_table;
         m_key2kana = &m_key2kana_normal;
         m_key2kana_tables.set_typing_method (method, fundamental_table);
-    }
-
-    if (method == SCIM_ANTHY_TYPING_METHOD_KANA)
-        m_key2kana_normal.set_case_sensitive (true);
-    else
         m_key2kana_normal.set_case_sensitive (false);
+    }
 }
 
 TypingMethod
