@@ -33,8 +33,6 @@ class AnthyInstance;
 
 namespace scim_anthy {
 
-typedef std::vector<KeyEvent> KeyEvents;
-
 typedef enum {
     SCIM_ANTHY_STRING_LATIN,
     SCIM_ANTHY_STRING_WIDE_LATIN,
@@ -61,7 +59,6 @@ public:
     void split (ReadingSegments &segments);
 
 private:
-//    KeyEvents  keys;
     String     raw;
     WideString kana;
 };
@@ -81,16 +78,8 @@ public:
                                         int              length = -1,
                                         StringType       type
                                         = SCIM_ANTHY_STRING_HIRAGANA);
-    void         get                   (WideString     & string,
-                                        unsigned int     start  = 0,
-                                        int              length = -1,
-                                        StringType       type
-                                        = SCIM_ANTHY_STRING_HIRAGANA);
     String       get_raw               (unsigned int     start  = 0,
                                         int              length = -1);
-    void         get_raw               (String         & string,
-                                        unsigned int     start  = 0,
-                                        int              length = -1);
     void         erase                 (unsigned int     start  = 0,
                                         int              length = -1,
                                         bool             allow_split = false);
